"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultSchemaLoader = void 0;
const graphql_1 = require("graphql");
const defaultSchemaLoader = (schemaConfig, parser) => {
    const { schema: graphQLSchema, documentAST, introspectionJSON, introspectionJSONString, buildSchemaOptions, documentString, } = schemaConfig;
    if (graphQLSchema) {
        return {
            schema: graphQLSchema,
            documentString: graphql_1.printSchema(graphQLSchema),
        };
    }
    if (introspectionJSONString) {
        const introspectionJSONResult = JSON.parse(introspectionJSONString);
        return {
            introspectionJSON: introspectionJSONResult,
            schema: graphql_1.buildClientSchema(introspectionJSONResult, buildSchemaOptions),
            introspectionJSONString,
        };
    }
    if (documentString) {
        const docAST = parser(documentString);
        return {
            schema: graphql_1.buildASTSchema(docAST, buildSchemaOptions),
            documentAST: docAST,
            documentString,
        };
    }
    if (introspectionJSON) {
        return {
            schema: graphql_1.buildClientSchema(introspectionJSON, buildSchemaOptions),
            introspectionJSON,
            introspectionJSONString: JSON.stringify(introspectionJSON),
        };
    }
    if (documentAST) {
        const schema = graphql_1.buildASTSchema(documentAST, buildSchemaOptions);
        return {
            schema,
            documentAST,
            documentString: graphql_1.printSchema(schema),
        };
    }
    throw Error('no schema supplied');
};
exports.defaultSchemaLoader = defaultSchemaLoader;
//# sourceMappingURL=schemaLoader.js.map