import { buildClientSchema, buildASTSchema, printSchema, } from 'graphql';
export const defaultSchemaLoader = (schemaConfig, parser) => {
    const { schema: graphQLSchema, documentAST, introspectionJSON, introspectionJSONString, buildSchemaOptions, documentString, } = schemaConfig;
    if (graphQLSchema) {
        return {
            schema: graphQLSchema,
            documentString: printSchema(graphQLSchema),
        };
    }
    if (introspectionJSONString) {
        const introspectionJSONResult = JSON.parse(introspectionJSONString);
        return {
            introspectionJSON: introspectionJSONResult,
            schema: buildClientSchema(introspectionJSONResult, buildSchemaOptions),
            introspectionJSONString,
        };
    }
    if (documentString) {
        const docAST = parser(documentString);
        return {
            schema: buildASTSchema(docAST, buildSchemaOptions),
            documentAST: docAST,
            documentString,
        };
    }
    if (introspectionJSON) {
        return {
            schema: buildClientSchema(introspectionJSON, buildSchemaOptions),
            introspectionJSON,
            introspectionJSONString: JSON.stringify(introspectionJSON),
        };
    }
    if (documentAST) {
        const schema = buildASTSchema(documentAST, buildSchemaOptions);
        return {
            schema,
            documentAST,
            documentString: printSchema(schema),
        };
    }
    throw Error('no schema supplied');
};
//# sourceMappingURL=schemaLoader.js.map